@@ -12,8 +12,8 @@
 #include <jg_jnu.h>
 #include <gtk_java.h>
 
-#ifndef _Included_org_gnu_gconf_ConfMetaInfo
-#define _Included_org_gnu_gconf_ConfMetaInfo
+#include "org_gnu_gconf_ConfMetaInfo.h"
+
 #ifdef __cplusplus
 extern "C" {
 #endif
@@ -113,4 +113,3 @@ JNIEXPORT void JNICALL Java_org_gnu_gconf_ConfMetaInfo_gconf_1meta_1info_1set_1m
 #ifdef __cplusplus
 }
 #endif
-#endif
